GrxAddressFormStrings class abstract

Localized strings required by GrxAddressForm.

Constructors

GrxAddressFormStrings()
const

Properties

addAddressNumberHelper String
no setter
addressAdministrativeAreaPlaceholder String
no setter
addressDependentLocalityPlaceholder String
no setter
addressLine1Label String
no setter
addressLine1Placeholder String
no setter
addressLine2Label String
no setter
addressLine2Placeholder String
no setter
addressLocalityPlaceholder String
no setter
addressNumberRequired String
no setter
addressPostalCodeInvalidBrCep String
no setter
addressPostalCodePlaceholder String
no setter
addressSearchError String
no setter
addressSearchHelperText String
no setter
administrativeArea String
no setter
cepNotFound String
no setter
country String
no setter
countryAR String
no setter
countryBR String
no setter
countryES String
no setter
countryMZ String
no setter
countryPT String
no setter
countryPY String
no setter
countryUS String
no setter
countryUY String
no setter
dependentLocality String
no setter
enterAddressSearch String
no setter
enterAdministrativeArea String
no setter
enterYourCountry String
no setter
hashCode int
The hash code for this object.
no setterinherited
invalidField String
no setter
locality String
no setter
noAddressResults String
no setter
postalCode String
no setter
removeAddress String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchAddress String
no setter
searchCep String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited