GrxPostalCodeRule class final

Postal code validation rule from schema.

Constructors

GrxPostalCodeRule({String? regex, List<String>? patterns, String? hint, bool stripNonDigits = false, List<String>? examples})
const
GrxPostalCodeRule.fromMap(Map<String, dynamic>? map)
factory

Properties

effectivePatterns List<String>
no setter
examples List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
patterns List<String>?
final
regex String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripNonDigits bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited