GrxPostalCodeUiModel class final

Postal code UI configuration from schema.

Constructors

GrxPostalCodeUiModel({String? inputType, String? mask, int? maxLength, String? hint, String? format})
const
GrxPostalCodeUiModel.fromMap(Map<String, dynamic>? map)
factory

Properties

format String?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
inputType String?
final
mask String?
final
maxLength int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited