GrxSubdivisionModel class final

Subdivision model (state/province/region) with ISO 3166-2 code and name.

Constructors

GrxSubdivisionModel({required String code, required String name})
const
GrxSubdivisionModel.fromMap(Map<String, dynamic> map)
factory

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited