GrxDialogService class abstract

Constructors

GrxDialogService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show<T>({required BuildContext context, required String title, String? description, Widget? content, List<Widget> actionsBuilder(BuildContext dialogContext)?, MainAxisAlignment actionsAlignment = MainAxisAlignment.end, bool barrierDismissible = true, bool showCloseButton = true, VoidCallback? onClose, EdgeInsets? insetPadding, double maxWidth = 400}) Future<T?>