GrxPostalCodeValidationResult class final

Result of schema-driven postal code validation.

Constructors

GrxPostalCodeValidationResult({required bool isValid, String? errorMessage})
const
GrxPostalCodeValidationResult.invalid(String message)
factory

Properties

errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

valid → const GrxPostalCodeValidationResult