GrxPostalCodeValidator class final

Centralized, schema-driven postal code validator.

Constructors

GrxPostalCodeValidator()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate({required String input, required GrxPostalCodeRule rule, bool isRequired = false}) GrxPostalCodeValidationResult

Operators

operator ==(Object other) bool
The equality operator.
inherited