GrxUpperCaseTextFormatter class

A TextInputFormatter that converts all input text to uppercase.

This formatter automatically converts any text entered into a text field to uppercase letters as the user types.

Example:

TextField(
  inputFormatters: [
    GrxUpperCaseTextFormatter(),
  ],
)
Inheritance

Constructors

GrxUpperCaseTextFormatter()
Creates a GrxUpperCaseTextFormatter.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited