GrxTextField class

Inheritance

Constructors

GrxTextField({Key? key, bool readOnly = false, TextInputType? keyboardType, bool obscureText = false, void onSubmitted(String)?, FocusNode? focusNode, bool autofocus = false, List<TextInputFormatter>? inputFormatters, VoidCallback? onTap, void onChanged(String)?, Iterable<String>? autofillHints, required TextEditingController controller, String? labelText, bool enabled = true, bool autocorrect = false, EdgeInsets? contentPadding, TextCapitalization textCapitalization = TextCapitalization.sentences, TextAlignVertical textAlignVertical = TextAlignVertical.center, int? maxLines = 1, bool alignLabelWithHint = false, String? hintText, int? hintMaxLines, String? errorText, TextInputAction textInputAction = TextInputAction.next, VoidCallback? onClear, bool showClearButton = true, Widget? prefix, Widget? suffix, TextStyle? style, BoxConstraints? suffixIconConstraints})
const

Properties

alignLabelWithHint bool
final
autocorrect bool
final
autofillHints Iterable<String>?
final
autofocus bool
final
contentPadding EdgeInsets?
final
controller TextEditingController
final
enabled bool
final
errorText String?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hintMaxLines int?
final
hintText String?
final
inputFormatters List<TextInputFormatter>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
final
labelText String?
final
maxLines int?
final
obscureText bool
final
onChanged → void Function(String)?
final
onClear VoidCallback?
final
onSubmitted → void Function(String)?
final
onTap VoidCallback?
final
prefix Widget?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showClearButton bool
final
style TextStyle?
final
suffix Widget?
final
suffixIconConstraints BoxConstraints?
final
textAlignVertical TextAlignVertical
final
textCapitalization TextCapitalization
final
textInputAction TextInputAction
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GrxTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited