GrxAddressFormDelegate class abstract
Network and backend operations for GrxAddressForm. Apps provide an implementation; the design system widget never calls HTTP directly.
Constructors
- GrxAddressFormDelegate()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
autocomplete(
{required String query, required String countryCode, String? session}) → Future< List< GrxAutocompleteItemModel> > -
fetchAvailableCountries(
) → Future< List< String> > -
fetchPlaceDetails(
{required String placeId, required String countryCode, String? session}) → Future< GrxCanonicalAddressModel> -
fetchSchema(
String countryCode) → Future< GrxAddressSchemaModel> -
lookupBrazilZipcode(
String digitsOnly) → Future< GrxCanonicalAddressModel?> -
normalizeAddress(
GrxCanonicalAddressModel address) → Future< GrxCanonicalAddressModel> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateAddress(
GrxCanonicalAddressModel address) → Future< void> - Throws GrxAddressValidationException when the address is invalid.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited