GrxAddressSchemaModel class final
Address schema model matching backend contract.
Constructors
-
GrxAddressSchemaModel({required String countryCode, required Map<
String, String> labels, required List<String> order, required List<String> required, GrxPostalCodeRule? postalCodeRule, GrxPostalCodeUiModel? postalCodeUi, List<String> ? notes, List<GrxSubdivisionModel> ? subdivisions}) -
const
-
GrxAddressSchemaModel.fromMap({required Map<
String, dynamic> map}) -
factory
Properties
- countryCode → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ Map<
String, String> -
final
-
notes
→ List<
String> ? -
final
-
order
→ List<
String> -
final
- postalCodeRule → GrxPostalCodeRule?
-
final
- postalCodeUi → GrxPostalCodeUiModel?
-
final
-
required
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subdivisions
→ List<
GrxSubdivisionModel> ? -
final
Methods
-
getFieldLabel(
String fieldName) → String? -
isFieldRequired(
String fieldName) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited